const system = require("../../../system");
const Dao = require("../../dao.base");
class SaasMerchantUserDao extends Dao {
  constructor() {
    super(Dao.getModelName(SaasMerchantUserDao));
  }

  /**
   * 条件查询
   * @param {} params 
   */
  async usersBySaasId(params) {
    let sql = [];
    sql.push("SELECT");
    sql.push("*");
    sql.push("FROM");
    sql.push(this.model.tableName);
    sql.push("WHERE 1 = 1 ");
    if (params.ucname) {
      sql.push("AND ucname = :ucname");
    }
    if (params.saas_merchant_id) {
      sql.push("AND saas_merchant_id = :saas_merchant_id");
    }
    if (params.saas_id) {
      sql.push("AND saas_id = :saas_id");
    }
    sql.push(`AND (deleted_at > NOW() or deleted_at is null)`);
    return await this.customQuery(sql.join(" "), params);
  }

  async byUcname(ucname, merchantId) {
    let sql = [];
    sql.push("SELECT");
    sql.push("*");
    sql.push("FROM");
    sql.push(this.model.tableName);
    sql.push("WHERE ucname = :ucname");
    let param = {ucname: ucname};

    if(merchantId) {
      sql.push("AND saas_merchant_id = :merchantId");
      param.merchantId = merchantId;
    }
    sql.push("AND deleted_at IS NULL");

    var list = await this.customQuery(sql.join(" "), param);
    if (!list || list.length == 0) {
      return null;
    }
    return list[0];
  }

  async countByCondition(params) {
    var sql = [];
    sql.push("SELECT");
    sql.push("count(1) as num");
    sql.push("FROM ");
    sql.push(this.model.tableName);
    sql.push("WHERE deleted_at IS NULL");

    this.setCondition(sql, params);

    var list = await this.customQuery(sql.join(" "), params);
    if (!list || list.length == 0) {
      return 0;
    }
    return list[0].num;
  }

  async listByCondition(params) {
    params.startRow = Number(params.startRow || 0);
    params.pageSize = Number(params.pageSize || 10);

    var sql = [];
    sql.push("SELECT");
    sql.push("*");
    sql.push("FROM");
    sql.push(this.model.tableName);
    sql.push("WHERE deleted_at IS NULL");

    this.setCondition(sql, params);

    sql.push("ORDER BY id DESC");
    sql.push("LIMIT :startRow, :pageSize");
    return await this.customQuery(sql.join(" "), params);
  }

  setCondition(sql, params) {
    if (!params || !sql) {
      return;
    }
    if (params.saas_id) {
      sql.push("AND saas_id = :saas_id");
    }
    if (params.saas_merchant_id) {
      sql.push("AND saas_merchant_id = :saas_merchant_id");
    }

    if (params.ucname) {
      sql.push("AND ucname LIKE :ucname");
    }

    if (params.mobile) {
      sql.push("AND mobile LIKE :mobile");
    }

    if (params.realName) {
      sql.push("AND realName LIKE :realName");
    }

    if (params.createBegin) {
      sql.push("AND created_at >= :createBegin");
    }

    if (params.createEnd) {
      sql.push("AND created_at <= :createEnd");
    }

    if (params.isEnabled === 0 || params.isEnabled === 1) {
      sql.push("AND isEnabled = :isEnabled");
    }
  }

  async mapByIds(ids, attrs) {
    let result = {};
    
    if (!ids || ids.length == 0) {
      return result;
    }
    let sql = [];
    sql.push("SELECT");
    sql.push(attrs || "*");
    sql.push("FROM");
    sql.push(this.model.tableName);
    sql.push("WHERE id IN (:ids)");

    var list = await this.customQuery(sql.join(" "), {
      ids: ids
    });
    if (!list || list.length == 0) {
      return result;
    }
    for (var item of list) {
      result[item.id] = item;
    }
    return result;
  }
  
}
module.exports = SaasMerchantUserDao;